import 'package:flutter/foundation.dart';
import 'package:flutter/painting.dart';

class PravatarImage extends ImageProvider<PravatarImage> {
  PravatarImage({
    required double size,
    int? imageId,
    String? uniqueId,
    Map<String, String>? headers,
  }) : _networkImage = NetworkImage(
          buildUrl(
            size: size,
            imageId: imageId,
            uniqueId: uniqueId,
          ),
        );

  final NetworkImage _networkImage;

  String get url => _networkImage.url;

  double get scale => _networkImage.scale;

  Map<String, String>? get headers => _networkImage.headers;

  @override
  ImageStreamCompleter load(PravatarImage key, DecoderCallback decode) =>
      _networkImage.load(key._networkImage, decode);

  @override
  Future<PravatarImage> obtainKey(ImageConfiguration configuration) {
    return SynchronousFuture<PravatarImage>(this);
  }

  static String buildUrl({
    required double size,
    int? imageId,
    String? uniqueId,
  }) {
    size = size.clamp(0, 1000);
    var result = 'https://i.pravatar.cc/${size.toInt()}';

    if (imageId != null) {
      result += '?img=$imageId';
    } else if (uniqueId != null) {
      result += '?u=${Uri.encodeQueryComponent(uniqueId)}';
    }

    return result;
  }
}
