import 'dart:math' as math;

import 'package:flutter/widgets.dart';

import 'image_provider.dart';

/// An [Image] with placholder images from [pravatar.cc].
class Pravatar extends StatelessWidget {
  /// Display a a random placholder avatar, different each time it is loaded.
  const Pravatar.random({
    Key? key,
    this.fit = BoxFit.cover,
    this.alignment = Alignment.center,
  })  : imageId = null,
        uniqueId = null,
        super(
          key: key,
        );

  /// Display the placholder avatar from its [imageId].
  ///
  /// All identifiers are available on [the website](https://pravatar.cc/images).
  Pravatar.imageId(
    int imageId, {
    this.fit = BoxFit.cover,
    this.alignment = Alignment.center,
  })  :
        // ignore: prefer_initializing_formals
        imageId = imageId,
        uniqueId = null,
        super(
          key: ValueKey(imageId),
        );

  /// Display the placholder avatar associated to the given [uniqueId].
  ///
  /// The avatar is guaranteed to be always the same as soon as the provided [uniqueId]
  /// is the same.
  Pravatar.uniqueId(
    String uniqueId, {
    this.fit = BoxFit.cover,
    this.alignment = Alignment.center,
  })  :
        // ignore: prefer_initializing_formals
        uniqueId = uniqueId,
        imageId = null,
        super(
          key: Key(uniqueId),
        );

  final int? imageId;
  final String? uniqueId;
  final BoxFit fit;
  final Alignment alignment;

  @override
  Widget build(BuildContext context) {
    return LayoutBuilder(
      builder: (context, constraints) {
        final devicePixelRatio = MediaQuery.of(context).devicePixelRatio;
        return Image(
          image: PravatarImage(
            size: devicePixelRatio *
                math.max(constraints.maxWidth, constraints.maxHeight),
            imageId: imageId,
            uniqueId: uniqueId,
          ),
          fit: fit,
          alignment: alignment,
        );
      },
    );
  }
}
